@@ -21,7 +21,7 @@ typedef struct _Efl_Loop_Arguments
 {
   const Eina_Array *argv; /**< Array with loop arguments */
   Eina_Bool initialization; /**< Set to @c true when the program should
-                             * initialize its internal state. This happen once
+                             * initialize its internal state. This happens once
                              * per process instance. */
 } Efl_Loop_Arguments;
 
@@ -110,7 +110,7 @@ EOAPI void efl_loop_quit(Eo *obj, Eina_Value exit_code);
  *
  * @ingroup Efl_Loop
  */
-EOAPI Eina_Future *efl_loop_job(Eo *obj);
+EOAPI Eina_Future *efl_loop_job(Eo *obj) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief Slow down the loop execution by forcing sleep for a small period of
@@ -197,7 +197,7 @@ EOAPI double efl_loop_time_get(const Eo *obj);
  *
  * @ingroup Efl_Loop
  */
-EOAPI Eina_Future *efl_loop_idle(Eo *obj);
+EOAPI Eina_Future *efl_loop_idle(Eo *obj) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief A future promise that will be resolved from a clean main loop context
@@ -213,40 +213,7 @@ EOAPI Eina_Future *efl_loop_idle(Eo *obj);
  *
  * @ingroup Efl_Loop
  */
-EOAPI Eina_Future *efl_loop_timeout(Eo *obj, double time);
-
-/**
- * @brief Will register a manager of a specific class to be answered by
- * eo.provider_find.
- *
- * @param[in] obj The object.
- * @param[in] klass The class provided by the registered provider.
- * @param[in] provider The provider for the newly registered class that has to
- * provide that said Efl.Class.
- *
- * @return @c true if successfully register, @c false otherwise.
- *
- * @since 1.22
- *
- * @ingroup Efl_Loop
- */
-EOAPI Eina_Bool efl_loop_register(Eo *obj, const Efl_Class *klass, const Efl_Object *provider);
-
-/**
- * @brief Will unregister a manager of a specific class that was previously
- * registered and answered by eo.provider_find.
- *
- * @param[in] obj The object.
- * @param[in] klass The class provided by the provider to unregister for.
- * @param[in] provider The provider for the registered class to unregister.
- *
- * @return @c true if successfully unregistered, @c false otherwise.
- *
- * @since 1.22
- *
- * @ingroup Efl_Loop
- */
-EOAPI Eina_Bool efl_loop_unregister(Eo *obj, const Efl_Class *klass, const Efl_Object *provider);
+EOAPI Eina_Future *efl_loop_timeout(Eo *obj, double time) EFL_TRANSFER_OWNERSHIP;
 
 EWAPI extern const Efl_Event_Description _EFL_LOOP_EVENT_IDLE_ENTER;
 
@@ -293,7 +260,7 @@ EWAPI extern const Efl_Event_Description _EFL_LOOP_EVENT_ARGUMENTS;
 EWAPI extern const Efl_Event_Description _EFL_LOOP_EVENT_POLL_HIGH;
 
 /** Event occurs multiple times per second. The exact tick is undefined and can
- * be adjusted system wide.
+ * be adjusted system-wide.
  *
  * @since 1.22
  *
@@ -304,7 +271,7 @@ EWAPI extern const Efl_Event_Description _EFL_LOOP_EVENT_POLL_HIGH;
 EWAPI extern const Efl_Event_Description _EFL_LOOP_EVENT_POLL_MEDIUM;
 
 /** Event occurs multiple times per minute. The exact tick is undefined and can
- * be adjusted system wide.
+ * be adjusted system-wide.
  *
  * @since 1.22
  *
@@ -315,7 +282,7 @@ EWAPI extern const Efl_Event_Description _EFL_LOOP_EVENT_POLL_MEDIUM;
 EWAPI extern const Efl_Event_Description _EFL_LOOP_EVENT_POLL_LOW;
 
 /** Event occurs multiple times every 15 minutes. The exact tick is undefined
- * and can be adjusted system wide.
+ * and can be adjusted system-wide.
  *
  * @since 1.22
  *
