@@ -13,9 +13,8 @@ typedef Eo Efl_Net_Server_Fd;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** A generic server based on file descriptors.
- *
- * @since 1.19
  *
  * @ingroup Efl_Net_Server_Fd
  */
@@ -64,8 +63,6 @@ EWAPI const Efl_Class *efl_net_server_fd_class_get(void);
  * @return $0 on success, ENOENT if no socket is available or EALREADY if
  * already have a socket
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Fd
  */
 EOAPI Eina_Error efl_net_server_fd_socket_activate(Eo *obj, const char *address);
@@ -82,8 +79,6 @@ EOAPI Eina_Error efl_net_server_fd_socket_activate(Eo *obj, const char *address)
  * @param[in] obj The object.
  * @param[in] family Socket address family
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Fd
  */
 EOAPI void efl_net_server_fd_family_set(Eo *obj, int family);
@@ -101,8 +96,6 @@ EOAPI void efl_net_server_fd_family_set(Eo *obj, int family);
  *
  * @return Socket address family
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Fd
  */
 EOAPI int efl_net_server_fd_family_get(const Eo *obj);
@@ -120,8 +113,6 @@ EOAPI int efl_net_server_fd_family_get(const Eo *obj);
  *
  * @return @c true on success, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Fd
  */
 EOAPI Eina_Bool efl_net_server_fd_close_on_exec_set(Eo *obj, Eina_Bool close_on_exec);
@@ -137,8 +128,6 @@ EOAPI Eina_Bool efl_net_server_fd_close_on_exec_set(Eo *obj, Eina_Bool close_on_
  *
  * @return If @c true close on exec will be used, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Fd
  */
 EOAPI Eina_Bool efl_net_server_fd_close_on_exec_get(const Eo *obj);
@@ -152,8 +141,6 @@ EOAPI Eina_Bool efl_net_server_fd_close_on_exec_get(const Eo *obj);
  *
  * @return @c true on success, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Fd
  */
 EOAPI Eina_Bool efl_net_server_fd_reuse_address_set(Eo *obj, Eina_Bool reuse_address);
@@ -165,8 +152,6 @@ EOAPI Eina_Bool efl_net_server_fd_reuse_address_set(Eo *obj, Eina_Bool reuse_add
  *
  * @return If @c true the server will reuse the address, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Fd
  */
 EOAPI Eina_Bool efl_net_server_fd_reuse_address_get(const Eo *obj);
@@ -180,8 +165,6 @@ EOAPI Eina_Bool efl_net_server_fd_reuse_address_get(const Eo *obj);
  *
  * @return @c true on success, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Fd
  */
 EOAPI Eina_Bool efl_net_server_fd_reuse_port_set(Eo *obj, Eina_Bool reuse_port);
@@ -193,8 +176,6 @@ EOAPI Eina_Bool efl_net_server_fd_reuse_port_set(Eo *obj, Eina_Bool reuse_port);
  *
  * @return If @c true the server will reuse the port, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Fd
  */
 EOAPI Eina_Bool efl_net_server_fd_reuse_port_get(const Eo *obj);
@@ -211,11 +192,8 @@ EOAPI Eina_Bool efl_net_server_fd_reuse_port_get(const Eo *obj);
  * It is called straight from @ref Efl_Loop_Fd "read" event handler and is
  * provided as a method to allow easy extending of the class for various
  * purposes.
- *
  * @param[in] obj The object.
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Fd
  */
 EOAPI void efl_net_server_fd_process_incoming_data(Eo *obj);
@@ -240,8 +218,6 @@ EOAPI void efl_net_server_fd_process_incoming_data(Eo *obj);
  * @param[in] client_fd The file descriptor of the client socket. It comes
  * preconfigured with close_on_exec. On failure, remember to close this socket.
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Fd
  */
 EOAPI void efl_net_server_fd_client_add(Eo *obj, int client_fd);
@@ -258,11 +234,10 @@ EOAPI void efl_net_server_fd_client_add(Eo *obj, int client_fd);
  * preconfigured with close_on_exec and should be closed once it's not needed
  * anymore
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Fd
  */
 EOAPI void efl_net_server_fd_client_reject(Eo *obj, int client_fd);
 #endif
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
