@@ -11,20 +11,29 @@ typedef Eo Efl_Net_Socket_Ssl;
 #ifndef _EFL_NET_SOCKET_SSL_EO_TYPES
 #define _EFL_NET_SOCKET_SSL_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
+EWAPI Eina_Error efl_net_socket_ssl_error_handshake_get(void);
+
 /** Failed SSL handshake
  *
  * @ingroup Efl_Net_Socket_Ssl_Error
  */
-EWAPI extern Eina_Error EFL_NET_SOCKET_SSL_ERROR_HANDSHAKE;
+#define EFL_NET_SOCKET_SSL_ERROR_HANDSHAKE efl_net_socket_ssl_error_handshake_get()
+#endif /* EFL_BETA_API_SUPPORT */
+
+#ifdef EFL_BETA_API_SUPPORT
+EWAPI Eina_Error efl_net_socket_ssl_error_certificate_verify_failed_get(void);
 
 /** Failed to verify peer's certificate
  *
  * @ingroup Efl_Net_Socket_Ssl_Error
  */
-EWAPI extern Eina_Error EFL_NET_SOCKET_SSL_ERROR_CERTIFICATE_VERIFY_FAILED;
+#define EFL_NET_SOCKET_SSL_ERROR_CERTIFICATE_VERIFY_FAILED efl_net_socket_ssl_error_certificate_verify_failed_get()
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief A wrapper socket doing SSL (Secure Sockets Layer).
  *
@@ -33,8 +42,6 @@ EWAPI extern Eina_Error EFL_NET_SOCKET_SSL_ERROR_CERTIFICATE_VERIFY_FAILED;
  * @ref Efl_Net_Dialer_Tcp or @ref Efl_Net_Server_Tcp created with "client,add"
  * event.
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Ssl
  */
 #define EFL_NET_SOCKET_SSL_CLASS efl_net_socket_ssl_class_get()
@@ -55,8 +62,6 @@ EWAPI const Efl_Class *efl_net_socket_ssl_class_get(void);
  * @param[in] efl_net_socket The socket to adopt
  * @param[in] ctx The SSL context to use when adopting the socket
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Ssl
  */
 EOAPI void efl_net_socket_ssl_adopt(Eo *obj, Efl_Net_Socket *efl_net_socket, Efl_Net_Ssl_Context *ctx);
@@ -66,14 +71,12 @@ EOAPI void efl_net_socket_ssl_adopt(Eo *obj, Efl_Net_Socket *efl_net_socket, Efl
  * @brief Return the adopted object, if any. Be careful!
  *
  * @param[in] obj The object.
- * @param[out] efl_net_socket The adopted object, if any, otherwise NULL
+ * @param[out] efl_net_socket The adopted object, if any, otherwise @c NULL
  * @param[out] ctx The SSL context used when adopting the socket, if any,
- * otherwise NULL
+ * otherwise @c NULL
  *
  * @return @c true if adopted, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Ssl
  */
 EOAPI Eina_Bool efl_net_socket_ssl_adopted_get(const Eo *obj, Efl_Net_Socket **efl_net_socket, Efl_Net_Ssl_Context **ctx);
@@ -85,8 +88,6 @@ EOAPI Eina_Bool efl_net_socket_ssl_adopted_get(const Eo *obj, Efl_Net_Socket **e
  * @param[in] obj The object.
  * @param[in] verify_mode Remote verification mode
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Ssl
  */
 EOAPI void efl_net_socket_ssl_verify_mode_set(Eo *obj, Efl_Net_Ssl_Verify_Mode verify_mode);
@@ -98,8 +99,6 @@ EOAPI void efl_net_socket_ssl_verify_mode_set(Eo *obj, Efl_Net_Ssl_Verify_Mode v
  *
  * @return Remote verification mode
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Ssl
  */
 EOAPI Efl_Net_Ssl_Verify_Mode efl_net_socket_ssl_verify_mode_get(const Eo *obj);
@@ -114,8 +113,6 @@ EOAPI Efl_Net_Ssl_Verify_Mode efl_net_socket_ssl_verify_mode_get(const Eo *obj);
  * @param[in] hostname_verify @c true if the hostname will be verified,
  * @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Ssl
  */
 EOAPI void efl_net_socket_ssl_hostname_verify_set(Eo *obj, Eina_Bool hostname_verify);
@@ -130,8 +127,6 @@ EOAPI void efl_net_socket_ssl_hostname_verify_set(Eo *obj, Eina_Bool hostname_ve
  *
  * @return @c true if the hostname will be verified, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Ssl
  */
 EOAPI Eina_Bool efl_net_socket_ssl_hostname_verify_get(const Eo *obj);
@@ -142,7 +137,7 @@ EOAPI Eina_Bool efl_net_socket_ssl_hostname_verify_get(const Eo *obj);
  * Most of time this is useful if you're using an IP address but the server
  * certificate only specifies DNS (names).
  *
- * If NULL, then it will fetch from socket using
+ * If @c NULL, then it will fetch from socket using
  * @ref efl_net_socket_address_remote_get or
  * @ref efl_net_dialer_address_dial_get.
  *
@@ -151,8 +146,6 @@ EOAPI Eina_Bool efl_net_socket_ssl_hostname_verify_get(const Eo *obj);
  * @param[in] obj The object.
  * @param[in] hostname_override Hostname for this socket
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Ssl
  */
 EOAPI void efl_net_socket_ssl_hostname_override_set(Eo *obj, const char *hostname_override);
@@ -163,7 +156,7 @@ EOAPI void efl_net_socket_ssl_hostname_override_set(Eo *obj, const char *hostnam
  * Most of time this is useful if you're using an IP address but the server
  * certificate only specifies DNS (names).
  *
- * If NULL, then it will fetch from socket using
+ * If @c NULL, then it will fetch from socket using
  * @ref efl_net_socket_address_remote_get or
  * @ref efl_net_dialer_address_dial_get.
  *
@@ -173,8 +166,6 @@ EOAPI void efl_net_socket_ssl_hostname_override_set(Eo *obj, const char *hostnam
  *
  * @return Hostname for this socket
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Ssl
  */
 EOAPI const char *efl_net_socket_ssl_hostname_override_get(const Eo *obj);
@@ -184,8 +175,6 @@ EWAPI extern const Efl_Event_Description _EFL_NET_SOCKET_SSL_EVENT_SSL_READY;
 /** Notifies the SSL handshake has been performed and the socket is now able to
  * communicate
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Ssl
  */
 #define EFL_NET_SOCKET_SSL_EVENT_SSL_READY (&(_EFL_NET_SOCKET_SSL_EVENT_SSL_READY))
@@ -195,10 +184,9 @@ EWAPI extern const Efl_Event_Description _EFL_NET_SOCKET_SSL_EVENT_SSL_ERROR;
 /** An error such as @ref Efl_Net_Socket_Ssl_Error_HANDSHAKE
  * @return Eina_Error
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Ssl
  */
 #define EFL_NET_SOCKET_SSL_EVENT_SSL_ERROR (&(_EFL_NET_SOCKET_SSL_EVENT_SSL_ERROR))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
