@@ -4,11 +4,15 @@
 #ifndef _EFL_NET_TYPES_EOT_TYPES
 #define _EFL_NET_TYPES_EOT_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
+EWAPI Eina_Error efl_net_error_couldnt_resolve_host_get(void);
+
 /** Could not resolve the given host name
  *
  * @ingroup Efl_Net_Error
  */
-EWAPI extern Eina_Error EFL_NET_ERROR_COULDNT_RESOLVE_HOST;
+#define EFL_NET_ERROR_COULDNT_RESOLVE_HOST efl_net_error_couldnt_resolve_host_get()
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
