@@ -47,7 +47,7 @@ EOAPI Eina_Bool efl_config_set(Eo *obj, const char *name, const Eina_Value *valu
  *
  * @ingroup Efl_Config
  */
-EOAPI Eina_Value *efl_config_get(const Eo *obj, const char *name);
+EOAPI Eina_Value *efl_config_get(const Eo *obj, const char *name) EFL_TRANSFER_OWNERSHIP;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
