@@ -13,67 +13,79 @@ typedef Eo Efl_Gfx_Gradient_Radial;
 
 
 #endif
-#define EFL_GFX_GRADIENT_RADIAL_INTERFACE efl_gfx_gradient_radial_interface_get()
-
-EWAPI const Eo_Class *efl_gfx_gradient_radial_interface_get(void);
-
-/**
- * @brief Gets the center of this radial gradient.
- *
- * @param[out] x x co-ordinate of center point
- * @param[out] y y co-ordinate of center point
+#ifdef EFL_BETA_API_SUPPORT
+/** Efl graphics gradient radial interface
  *
  * @ingroup Efl_Gfx_Gradient_Radial
  */
-EOAPI void efl_gfx_gradient_radial_center_get(const Eo *obj, double *x, double *y);
+#define EFL_GFX_GRADIENT_RADIAL_INTERFACE efl_gfx_gradient_radial_interface_get()
+
+EWAPI const Efl_Class *efl_gfx_gradient_radial_interface_get(void);
 
 /**
- * @brief Sets the center of this radial gradient.
+ * @brief The center of this radial gradient.
  *
- * @param[in] x x co-ordinate of center point
- * @param[in] y y co-ordinate of center point
+ * @param[in] obj The object.
+ * @param[in] x X co-ordinate of center point
+ * @param[in] y Y co-ordinate of center point
  *
  * @ingroup Efl_Gfx_Gradient_Radial
  */
 EOAPI void efl_gfx_gradient_radial_center_set(Eo *obj, double x, double y);
 
 /**
- * @brief Gets the center radius of this radial gradient.
+ * @brief The center of this radial gradient.
  *
- * @return center radius
+ * @param[in] obj The object.
+ * @param[out] x X co-ordinate of center point
+ * @param[out] y Y co-ordinate of center point
  *
  * @ingroup Efl_Gfx_Gradient_Radial
  */
-EOAPI double efl_gfx_gradient_radial_radius_get(const Eo *obj);
+EOAPI void efl_gfx_gradient_radial_center_get(const Eo *obj, double *x, double *y);
 
 /**
- * @brief Sets the center radius of this radial gradient.
+ * @brief The radius of this radial gradient.
  *
- * @param[in] r center radius
+ * @param[in] obj The object.
+ * @param[in] r Center radius
  *
  * @ingroup Efl_Gfx_Gradient_Radial
  */
 EOAPI void efl_gfx_gradient_radial_radius_set(Eo *obj, double r);
 
 /**
- * @brief Gets the focal point of this radial gradient.
+ * @brief The radius of this radial gradient.
  *
- * @param[out] x x co-ordinate of focal point
- * @param[out] y y co-ordinate of focal point
+ * @param[in] obj The object.
+ *
+ * @return Center radius
  *
  * @ingroup Efl_Gfx_Gradient_Radial
  */
-EOAPI void efl_gfx_gradient_radial_focal_get(const Eo *obj, double *x, double *y);
+EOAPI double efl_gfx_gradient_radial_radius_get(const Eo *obj);
 
 /**
- * @brief Sets the focal point of this radial gradient.
+ * @brief The focal point of this radial gradient.
  *
- * @param[in] x x co-ordinate of focal point
- * @param[in] y y co-ordinate of focal point
+ * @param[in] obj The object.
+ * @param[in] x X co-ordinate of focal point
+ * @param[in] y Y co-ordinate of focal point
  *
  * @ingroup Efl_Gfx_Gradient_Radial
  */
 EOAPI void efl_gfx_gradient_radial_focal_set(Eo *obj, double x, double y);
 
+/**
+ * @brief The focal point of this radial gradient.
+ *
+ * @param[in] obj The object.
+ * @param[out] x X co-ordinate of focal point
+ * @param[out] y Y co-ordinate of focal point
+ *
+ * @ingroup Efl_Gfx_Gradient_Radial
+ */
+EOAPI void efl_gfx_gradient_radial_focal_get(const Eo *obj, double *x, double *y);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
