@@ -13,13 +13,14 @@ typedef Eo Efl_Ui_Focus_Manager_Sub;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief A class that automatically registeres its border elements in the
- * parent manager
+ * @brief A class that automatically registers its border elements in the
+ * parent manager.
  *
  * This sub manager will register its border elements on the parent manager.
- * The parent manager is found with the @ref Efl_Ui_Focus_User interface of the
- * @ref efl_parent_get.
+ * The parent manager is found with the @ref Efl_Ui_Focus_Object interface of
+ * the @ref efl_parent_get.
  *
  * Each sub manager also has to be a focus object, the object itself will be
  * registered into the parent manager. It will be used as logical parent while
@@ -28,18 +29,11 @@ typedef Eo Efl_Ui_Focus_Manager_Sub;
  * You can filter the border elements by overriding the property
  * @ref efl_ui_focus_manager_border_elements_get.
  *
- * This class is only working as composite object to a @ref Efl_Ui_Focus_User
- * and @ref Efl_Ui_Focus_Object.
- *
- * The object itself redirects the manager's events to the object where this
- * object is attached.
- *
- * @since 1.20
- *
  * @ingroup Efl_Ui_Focus_Manager_Sub
  */
-#define EFL_UI_FOCUS_MANAGER_SUB_CLASS efl_ui_focus_manager_sub_class_get()
+#define EFL_UI_FOCUS_MANAGER_SUB_MIXIN efl_ui_focus_manager_sub_mixin_get()
 
-EWAPI const Efl_Class *efl_ui_focus_manager_sub_class_get(void);
+EWAPI const Efl_Class *efl_ui_focus_manager_sub_mixin_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
