@@ -13,6 +13,7 @@ typedef Eo Elm_Multibuttonentry_Part;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Elementary multibuttonentry internal part class
  *
  * @ingroup Elm_Multibuttonentry_Part
@@ -20,5 +21,6 @@ typedef Eo Elm_Multibuttonentry_Part;
 #define ELM_MULTIBUTTONENTRY_PART_CLASS elm_multibuttonentry_part_class_get()
 
 EWAPI const Efl_Class *elm_multibuttonentry_part_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
